<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Shpjegoje</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Përktheni</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Pyetni AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Përmbledhje</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Që të ndalet regjistrimi, 
klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Mos e rrotulloni ekranin tuaj gjatë regjistrimit</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Regjistrim</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Mbylle (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopjo te papastër (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Regjistrim Ekrani</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ruajtja dështoi. Ju lutemi, ruajeni te drejtoria juaj shtëpi.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Shihni</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Fotoja e ekranit u bë</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Fillo/Regjistrim</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>U ruajt te %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Shpërfille</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>E papastër</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Po ruhet kartela e regjistrimit të ekranit, ju lutemi, pritni…</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Ngaqë efekti i dritares është çaktivizuar gjatë procesit, regjistrimi duhet të ndalet.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Foto ekrani me rrëshqitje</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fiksoni Foto Ekrani</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Hapni Dosje</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Fotoja e ekranit u bë dhe u kopjua te papastër</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Zhbëje</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cdo pyetje</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Vendndodhje Specifikuar</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Caktoni shteg gjatë ruajtjes</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Foto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fiksoni Foto Ekrani</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Regjistroje</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Regjistrim</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Shihni</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Regjistrimi përfundoi</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>U ruajt te %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Regjistroje</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Hapni Dosje</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cdo pyetje</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Vendndodhje Specifikuar</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Zgjidhni vendndodhjen gjatë ruajtjes</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Përditësoni vendndodhjen gjatë ruajtjes</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Foto</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Regjistrimi i Ekranit do të fillojë për %1 sekonda</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Merrni ndihmë.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>S’u arrit të bëhet një foto e vazhdueshme.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>U mbërrit në fund të fushës së rrëshqitjes</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>U mbërrit në maksimumin e gjatësisë</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>rregulloni zonën që regjistrohet</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Që të bëhet një foto ekrani, rrotulloni rrotëzën e miut tuaj, ose klikoni</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Ngadalësoni shpejtësi rrotullimi</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Zonë e pavlefshme, klikoni për</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Futni tekst këtu</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Fillo/Foto Ekrani</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Dil/Ruaje</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Përimtim Madhësie</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Nisje e shpejtë</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Foto ekrani e dritares</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Vonoje foton e ekranit</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Foto ekrani e plotë</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Ruaje</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Drejtkëndësh</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Vijë</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Laps</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Zhbëje</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Rrit lartësinë sipër</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Rrit lartësinë poshtë</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Rrit gjerësinë majtas</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Rrit gjerësinë djathtas</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Zvogëlo lartësinë sipër</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Zvogëlo lartësinë poshtë</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Zvogëlo gjerësinë majtas</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Zvogëlo gjerësinë djathtas</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Tingull</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Shtypje tastesh</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamerë Web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Fillo regjistrim</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Mundësi</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Fillo/Regjistrim</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Mjete</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Përfto tekst</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Foto ekrani me rrëshqitje</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fiksoni foto ekrani</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Nis OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Fillo foto ekrani me rrëshqitje</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Shigjetë</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Regjistroje</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Drejtkëndësh
Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një kuadrat</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elips
Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një rreth</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Penel
Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë e drejtë</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Rregulloni fortësi turbullimi (Për ta rregulluar, rrëshqitni)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Rregulloni madhësi peneli (Për ta rregulluar, rrëshqitni)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Rregulloni madhësi teksti (Për ta rregulluar, rrëshqitni)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Shfaq varg tastesh për shtypje (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Fshih Varg Tastesh Për Shtypje (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Shfaq Varg Tastesh Për Shtypje (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Hapni kamerën (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Mbyllni kamerën (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Foto ekrani</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Rregullime (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>KPS</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 kps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 kps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 kps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 kps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 kps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Tingull</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio sistemi</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Mundësi</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Shfaq treguesin</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Shfaq klikim</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Ruaje te</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Vijë (L)
Shtypni dhe mbani të shtypur tastin Shift që të vizatohet një vijë vertikale ose horizontale</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Shigjetë (X)
Shtypni dhe mbani të shtypur tastin Shift, që të vizatohet një shigjetë vertikale ose horizontale</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Laps (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Turbulloje (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Foto ekrani me rrëshqitje (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Përfto tekstin (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fiksoni foto ekrani (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Zhbëje (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Regjistro</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efekte Anësh</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Asnjë</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Hije</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Anë</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Pajisje</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Përfto Tekst</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Mjete Geometrike (R)
Mbani të shtypur tastin Shift që të vizatohet një drejtkëndësh ose një rreth.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Ruaje te lokali</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Ruaje te %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Vendndodhje Specifikuar</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Përditësoni vendndodhjen gjatë ruajtjes</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Zgjidhni vendndodhjen gjatë ruajtjes</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>Foto ekrani AI (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Ruaje te Desktop</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Ruaje te Foto</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Mbylle (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Kopjo te papastër (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Që të keni efekt video më të mirë, përshtatni zonën e regjistrimit brenda %1*%2</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Regjistrimet e ekranit hëpërhë nuk mbulohen</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
</TS>
